@@ -34,7 +34,7 @@ class Abstract:
     def book_meta(self) -> dict:
         pass
 
-    def loop_callback_chapters(self):
+    def before_download_chapter(self):
         pass
 
     def get_cover(self):
@@ -45,3 +45,7 @@ class Abstract:
 
     def after_file_save(self, _path: str, idx: int):
         pass
+
+    @abstractmethod
+    def chapter_for_json(self) -> str:
+        pass
