@@ -3,6 +3,7 @@ from zipfile import ZipFile, ZIP_DEFLATED
 # from PIL import Image as PilImage
 from manga_py.image import Image
 from os import path
+from time import sleep
 
 from manga_py.fs import is_file, make_dirs, basename, dirname, unlink, get_temp_path
 
@@ -12,6 +13,7 @@ class Archive:
     _writes = None
     files = None
     not_change_files_extension = False
+    no_webp = False
 
     def __init__(self):
         self.files = []
@@ -34,7 +36,13 @@ class Archive:
     def __add_files(self):
         for file in self.files:
             if is_file(file[0]):
-                self._archive.write(file[0], file[1])
+                ext = self.__update_image_extension(file[0])
+                if self.no_webp and ext[ext.rfind('.'):] == '.webp':
+                    jpeg = ext[:ext.rfind('.')] + '.jpeg'
+                    jpeg_path = path.join(dirname(file[0]), jpeg)
+                    Image(file[0]).convert(jpeg_path)
+                    file = jpeg_path, jpeg
+                self._archive.write(*file)
 
     def __add_writes(self):
         for file in self._writes:
@@ -50,8 +58,13 @@ class Archive:
         make_dirs(dirname(dst))
 
         self._archive = ZipFile(dst, 'w', ZIP_DEFLATED)
-        self.__add_files()
-        self.__add_writes()
+        try:
+            self.__add_files()
+            self.__add_writes()
+            self._archive.close()
+        except OSError as e:
+            self._archive.close()
+            raise e
         self._archive.close()
         self._maked()
 
@@ -59,13 +72,10 @@ class Archive:
         for file in self.files:
             unlink(file[0])
 
-    def __update_image_extension(self, filename) -> tuple:
+    def __update_image_extension(self, filename) -> str:
         fn, extension = path.splitext(filename)
         if not self.not_change_files_extension:
             ext = Image.real_extension(get_temp_path(filename))
             if ext:
                 extension = ext
         return basename(fn + extension)
-
-    def lazy_add(self, _path):
-        self.add_file(_path, self.__update_image_extension(_path))
