@@ -1,6 +1,7 @@
 from time import sleep
+from sys import stderr
 
-from manga_py.fs import get_temp_path, make_dirs, remove_file_query_params, basename, path_join, dirname
+from manga_py.fs import get_temp_path, make_dirs, remove_file_query_params, basename, path_join, dirname, file_size
 from .multi_threads import MultiThreads
 from .request import Request
 from .url_normalizer import normalize_uri
@@ -45,6 +46,7 @@ class Http(Request):
                         response.status_code,
                         url,
                     ))
+                    sleep(2)
                     continue
                 out_file.write(response.content)
                 response.close()
@@ -61,11 +63,13 @@ class Http(Request):
             return False
         return True
 
-    def _download_one_file_helper(self, url, dst, callback: callable = None, success_callback: callable = None):
+    def _download_one_file_helper(self, url, dst, callback: callable = None, success_callback: callable = None, callback_args=()):
         r = 0
         while r < self.count_retries:
             if self._safe_downloader(url, dst):
-                success_callback and success_callback(dst)
+                if file_size(dst) < 128:
+                    print('\nWarning: 0 bit image downloaded, please check for redirection or broken content', file=stderr)
+                callable(success_callback) and success_callback(dst, *callback_args)
                 return True
 
             r += 1
@@ -78,11 +82,11 @@ class Http(Request):
     def download_file(self, url: str,
                       dst: str = None,
                       callback: callable = None,
-                      success_callback: callable = None) -> bool:
+                      success_callback: callable = None, callback_args=()) -> bool:
         if not dst:
             name = basename(remove_file_query_params(url))
             dst = path_join(get_temp_path(), name)
-        return self._download_one_file_helper(url, dst, callback, success_callback)
+        return self._download_one_file_helper(url, dst, callback, success_callback, callback_args)
 
     def normalize_uri(self, uri, referer=None):
         if not referer:
