@@ -1,6 +1,7 @@
 import json
 import re
 from abc import ABCMeta
+from sys import stderr, exit
 
 from .base_classes import (
     Abstract,
@@ -17,6 +18,8 @@ from .fs import (
     basename,
     remove_file_query_params,
     path_join,
+    unlink,
+    file_size,
 )
 from .http import MultiThreads
 from .meta import __downloader_uri__
@@ -47,8 +50,9 @@ class Provider(Base, Abstract, Static, Callbacks, metaclass=ABCMeta):
             (params.get('xt', 0),
              params.get('xr', 0),
              params.get('xb', 0),
-             params.get('xl', 0))
+             params.get('xl', 0)),
         )
+        self._image_params['no_webp'] = params.get('no_webp', False)
         # downloading params
         self._set_if_not_none(self._params, 'destination', params.get('destination', None))
         self._zero_fill = params.get('zero_fill')
@@ -81,30 +85,33 @@ class Provider(Base, Abstract, Static, Callbacks, metaclass=ABCMeta):
 
         return not_allow_archive and is_file(_path)
 
+    def _download_chapter(self, idx, _min, _max):
+        if idx < _min or (idx >= _max > 0) or self._check_archive():
+            return
+        if not self._simulate:
+            try:
+                self.before_download_chapter()
+                self._storage['files'] = self.get_files()
+                self.loop_files()
+            except Exception as e:
+                self._info.set_last_volume_error(e)
+
     def loop_chapters(self):
         volumes = self._storage['chapters']
         _min = self._params.get('skip_volumes', 0)
         _max = self._params.get('max_volumes', 0)
-        if _max > 0:
+        if _max > 0 and _min > 0:
             _max += _min - 1
         for idx, __url in enumerate(volumes):
             self._storage['current_chapter'] = idx
-
-            self._info.add_volume(self.chapter, self.get_archive_path())
-
-            if idx < _min or (idx > _max > 0) or self._check_archive():
-                continue
-
-            if not self._simulate:
-                self.loop_callback_chapters()
-
-                self._storage['files'] = self.get_files()
-                self.loop_files()
+            self._info.add_volume(self.chapter_for_json(), self.get_archive_path())
+            self._download_chapter(idx, _min, _max)
 
     def loop_files(self):
         if isinstance(self._storage['files'], list) and len(self._storage['files']) > 0:
             self._archive = Archive()
             self._archive.not_change_files_extension = self._params.get('not_change_files_extension', False)
+            self._archive.no_webp = self._image_params.get('no_webp', False)
             self._call_files_progress_callback()
 
             if self._params.get('no_multi_threads', False):
@@ -129,15 +136,12 @@ class Provider(Base, Abstract, Static, Callbacks, metaclass=ABCMeta):
     def save_file(self, idx=None, callback=None, url=None, in_arc_name=None):
         _path, idx, _url = self._save_file_params_helper(url, idx)
 
-        if not is_file(_path):
-            # issue 55
-            if in_arc_name is None:
-                self.http().download_file(_url, _path, success_callback=self._archive.lazy_add)
-            else:
-                self.http().download_file(_url, _path)
-                self._archive.add_file(_path, in_arc_name)
-        callable(callback) and callback()
+        if not is_file(_path) or file_size(_path) < 32:
+            self.http().download_file(_url, _path)
         self.after_file_save(_path, idx)
+        self._archive.add_file(_path)
+
+        callable(callback) and callback()
 
         return _path
 
@@ -170,7 +174,14 @@ class Provider(Base, Abstract, Static, Callbacks, metaclass=ABCMeta):
         #     self._archive.add_book_info(self._arc_meta_info())
 
         self._archive.add_info(info)
-        self._archive.make(_path)
+        try:
+            self._archive.make(_path)
+        except OSError as e:
+            print('')
+            print(e)
+            self.log(e, file=stderr)
+            self._info.set_last_volume_error(str(e))
+            unlink(_path)
 
     def html_fromstring(self, url, selector: str = None, idx: int = None):
         params = {}
@@ -198,7 +209,8 @@ class Provider(Base, Abstract, Static, Callbacks, metaclass=ABCMeta):
             self._storage['current_file'] = idx
             self._call_files_progress_callback()
             self.save_file()
-        self.progress()
+        _max = len(self._storage['files'])
+        self.progress(_max, _max)
 
     def cf_protect(self, url):
         """
@@ -209,7 +221,7 @@ class Provider(Base, Abstract, Static, Callbacks, metaclass=ABCMeta):
         cf = CloudFlareProtect()
         params = cf.run(url)
         if len(params):
-            self._storage['cookies'] = params[0]
+            self.update_cookies(params[0])
             self.update_ua(params[1])
             self._params['cf-protect'] = True
 
@@ -217,3 +229,8 @@ class Provider(Base, Abstract, Static, Callbacks, metaclass=ABCMeta):
         self._storage['user_agent'] = ua
         self.http().user_agent = ua
         self._info and self._info.set_ua(ua)
+
+    def update_cookies(self, cookies):
+        for k in cookies:
+            self._storage['cookies'][k] = cookies[k]
+            self.http().cookies[k] = cookies[k]
